==> koffice-1.2.1.tar.bz2: koffice-1.2.1/kpresenter/searchdia.h <==
/* This file is part of the KDE project
   Copyright (C) 2001, Laurent Montel <lmontel@mandrakesoft.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef searchdia_h
#define searchdia_h

#include "qrichtext_p.h"
#include "kptextobject.h"
#include <koSearchDia.h>

class KPrCanvas;
class KMacroCommand;
class KPTextView;
class KoTextObject;
class KoFindReplace;
class KoReplaceDia;
class KoSearchDia;
class KPTextView;
class KPrFindReplace;
class KCommand;
/**
 * This class implements the 'find' functionality ( the "search next, prompt" loop )
 * and the 'replace' functionality. Same class, to allow centralizing the code that
 * finds the framesets and paragraphs to look into.
 */
class KPrFindReplace : public KoFindReplace
{
    Q_OBJECT
public:
    KPrFindReplace( KPrCanvas * canvas, KoSearchDia * dialog , KPTextView *textView ,const QPtrList<KoTextObject> & lstObject);
    KPrFindReplace( KPrCanvas * canvas, KoReplaceDia * dialog, KPTextView *textView,const QPtrList<KoTextObject> & lstObject);
    ~KPrFindReplace();
    
    virtual void emitNewCommand(KCommand *);
    virtual void highlightPortion(KoTextParag * parag, int index, int length, KoTextDocument *textdoc);

private:
    KPrCanvas *m_canvas;
};

#endif

==> koffice-1.3.5.tar.bz2: koffice-1.3.5/kpresenter/searchdia.h <==
// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
/* This file is part of the KDE project
   Copyright (C) 2001, Laurent Montel <lmontel@mandrakesoft.com>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef searchdia_h
#define searchdia_h

#include "kptextobject.h"
#include <koSearchDia.h>

class KPrCanvas;
class KMacroCommand;
class KPTextView;
class KoTextObject;
class KoFindReplace;
class KoReplaceDia;
class KoSearchDia;
class KPTextView;
class KPrFindReplace;
class KCommand;
/**
 * This class implements the 'find' functionality ( the "search next, prompt" loop )
 * and the 'replace' functionality. Same class, to allow centralizing the code that
 * finds the framesets and paragraphs to look into.
 */
class KPrFindReplace : public KoFindReplace
{
    Q_OBJECT
public:
    /**
     * The parent widget can't be the canvas, otherwise the 'find next' dialog
     * scrolls up/down when using the scrollbars (hehe, cool effect).
     */
    KPrFindReplace( QWidget* parent, KPrCanvas * canvas, KoSearchDia * dialog,
                    const QValueList<KoTextObject *> & lstObjects, KPTextView *textView );
    KPrFindReplace( QWidget* parent, KPrCanvas * canvas, KoReplaceDia * dialog,
                    const QValueList<KoTextObject *> & lstObjects, KPTextView *textView );
    ~KPrFindReplace();

    virtual void emitNewCommand(KCommand *);
    virtual void highlightPortion(KoTextParag * parag, int index, int length, KoTextDocument *textdoc, KDialogBase* dialog);

private:
    KPrCanvas *m_canvas;
};

#endif
